Optional: Register with an Identity Provider
============================================

By default, there is no public link between your Matrix account and
any identifying information such as your email address.  However, you
may wish people to be able to find your Matrix ID by looking up your
email address or phone number.  We also have plans to add additional
functionality to our bots if they are able to look up contributors by
email addresses.  If you wish to make your account discoverable in
this way, you may perform the following steps to list your account in
one of the public third-party identifier services.  Note that these
services are designed to only return results for someone who already
knows your email address or phone number; they take care to ensure
that it is not possible (or nearly so) to "scrape" their data sets to
obtain lists of users.

To get started, open the User Menu and click `All settings`.  Under
the `General` section, find `Email addresses`.  If you followed the
instructions above, you should already have an email address listed
here.  If you don't, enter your address, click `Add`, and follow the
instructions to verify your address.  The dialog should look like this
when complete:

.. image:: /images/matrix/id-email-complete.png
   :align: center

To make your account discoverable by email, scroll down to the
`Discovery` section.

.. image:: /images/matrix/id-disc.png
   :align: center

Read the privacy notice and click the checkbox
next to `Accept`.  That will enable the `Continue` button; click that
to proceed.

.. image:: /images/matrix/id-disc-accept.png
   :align: center

The `Discovery` section will be replaced with the email address you
registered above.

.. image:: /images/matrix/id-disc-accept.png
   :align: center

Click the `Share` button next to the address.  The system will send an
email to you, and meanwhile the dialog will show this:

.. image:: /images/matrix/id-disc-verify-wait.png
   :align: center

You will receive an email like this:

.. image:: /images/matrix/id-disc-verify-email.png
   :align: center

Follow the link in the email to verify it really is you making the
request.

.. image:: /images/matrix/id-disc-verify-success.png
   :align: center

Then return to the settings page and click the `Complete` button.

.. image:: /images/matrix/id-disc-verify-wait.png
   :align: center

Once everything is finished, the complete button should change to read
`Revoke`.

.. image:: /images/matrix/id-disc-verify-complete.png
   :align: center

If you see that, you're all done.  If you change your mind and don't
want your account to be discoverable via email, you can click the
`Revoke` button at any time.
